@@ -1,7 +1,7 @@
 /*
  *   Jackbeat - JACK sequencer
  *    
- *   Copyright (c) 2004-2005 Olivier Guilyardi <olivier@samalyse.com>
+ *   Copyright (c) 2004-2006 Olivier Guilyardi <olivier {at} samalyse {dot} com>
  *    
  *   This program is free software; you can redistribute it and/or modify
  *   it under the terms of the GNU General Public License as published by
@@ -16,22 +16,23 @@
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the Free Software
  *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *
+ *   SVN:$Id: jab.h 50 2006-12-03 23:44:12Z olivier $
  */
 
 #ifndef JACKBEAT_JAB_H
 #define JACKBEAT_JAB_H
 
+#include "types.h"
 
 #define JAB_WRITE 1
 #define JAB_READ 2
 
 typedef struct jab_t jab_t;
-typedef void(* jab_progress_callback_t)(char * status, double fraction, void * data);
 
-jab_t * jab_open (char *path, int mode, jab_progress_callback_t progress_callback, 
-                  void *progress_data);
-void jab_add_sequence (jab_t *jab, sequence_t *sequence);
-sequence_t * jab_retrieve_sequence (jab_t *jab, char *sequence_name, int *error);
-int jab_close (jab_t *jab);
+jab_t *       jab_open (char *path, int mode, progress_callback_t progress_callback, void *progress_data);
+void          jab_add_sequence (jab_t *jab, sequence_t *sequence);
+sequence_t *  jab_retrieve_sequence (jab_t *jab, char *sequence_name, int *error);
+int           jab_close (jab_t *jab);
 
 #endif
